==> open-xchange-sso_6.16.1.0.orig.tar.gz: open-xchange-sso-6.16.1.0/src/com/openexchange/sso/osgi/SSOActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.sso.osgi;

import java.util.ArrayList;
import java.util.List;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;
import org.osgi.service.http.HttpService;
import org.osgi.util.tracker.ServiceTracker;
import com.openexchange.multiple.MultipleHandlerFactoryService;
import com.openexchange.sso.multiple.SSOMultipleHandlerFactory;

/**
 * {@link SSOActivator} - Activator for JSON single sign-on interface.
 * 
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class SSOActivator implements BundleActivator {

    private ServiceRegistration ssoMultipleService;

    private List<ServiceTracker> trackers;

    public void start(final BundleContext context) throws Exception {
        ssoMultipleService = context.registerService(MultipleHandlerFactoryService.class.getName(), new SSOMultipleHandlerFactory(), null);
        /*
         * Service trackers
         */
        trackers = new ArrayList<ServiceTracker>(1);
        trackers.add(new ServiceTracker(context, HttpService.class.getName(), new SSOServletRegisterer(context)));
        /*
         * Open trackers
         */
        for (final ServiceTracker tracker : trackers) {
            tracker.open();
        }
    }

    public void stop(final BundleContext context) throws Exception {
        if (null != trackers) {
            /*
             * Close trackers
             */
            while (!trackers.isEmpty()) {
                trackers.remove(0).close();
            }
            trackers = null;
        }
        if (null != ssoMultipleService) {
            ssoMultipleService.unregister();
            ssoMultipleService = null;
        }
    }

}

==> open-xchange-sso_6.20.8.0.orig.tar.gz: open-xchange-sso-6.20.8.0/src/com/openexchange/sso/osgi/SSOActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.sso.osgi;

import java.util.ArrayList;
import java.util.List;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;
import org.osgi.util.tracker.ServiceTracker;
import com.openexchange.multiple.MultipleHandlerFactoryService;
import com.openexchange.sso.SSOConstants;
import com.openexchange.sso.multiple.SSOMultipleHandlerFactory;
import com.openexchange.sso.servlet.SSOServlet;
import com.openexchange.tools.service.SessionServletRegistration;

/**
 * {@link SSOActivator} - Activator for JSON single sign-on interface.
 * 
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class SSOActivator implements BundleActivator {

    private ServiceRegistration ssoMultipleService;

    private List<ServiceTracker> trackers;

    public void start(final BundleContext context) throws Exception {
        ssoMultipleService = context.registerService(MultipleHandlerFactoryService.class.getName(), new SSOMultipleHandlerFactory(), null);
        /*
         * Service trackers
         */
        trackers = new ArrayList<ServiceTracker>(1);
        trackers.add(new SessionServletRegistration(context, new SSOServlet(), SSOConstants.SERVLET_PATH));
        /*
         * Open trackers
         */
        for (final ServiceTracker tracker : trackers) {
            tracker.open();
        }
    }

    public void stop(final BundleContext context) throws Exception {
        if (null != trackers) {
            /*
             * Close trackers
             */
            while (!trackers.isEmpty()) {
                trackers.remove(0).close();
            }
            trackers = null;
        }
        if (null != ssoMultipleService) {
            ssoMultipleService.unregister();
            ssoMultipleService = null;
        }
    }

}
